# -*- coding:UTF-8 -*-
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright (C) 2007 Stewart Adam
"""
The configuration file creator for livnaConfigDisplay. Based on ConfigParser, but changes are made immedately.
"""

"""
REMEMBER:
- No backups. This should be done in the code this _calling these_ functions.
"""

import ConfigParser

def toBool(string):
  if string.lower() == 'true':
    return True
  elif string.lower() == 'false':
    return False
  else:
    print 'DEBUG: %s is not \'true\' or \'false\'!' % string

class ConfigFile (ConfigParser.ConfigParser):
    """A more sane ConfigParser. It commits changes immediately, and
        also re-parses after each action so what-you-see-is-what's-in-the-file."""

    def __init__(self, conffile):
        """ Basic setup"""
        # OS portability stuff...
        ConfigParser.ConfigParser.__init__( self )
        self.config = ConfigParser.ConfigParser()
        self.conffile = conffile
        self.read()

    def read(self):
        """Read & parse the config file."""
        try:
            self.fh = open(self.conffile,'r')
            self.config.readfp(self.fh)
            self.fh.close()
        except IOError:
            self.fh = open(self.conffile,'w')
            self.fh.write('')
            self.fh.close()
            self.read()
            self.write()

    def write(self):
        """Write the config file, _then reparse_."""
        self.fh = open(self.conffile,'w')
        self.config.write(self.fh)
        self.fh.close()
        self.read()
        return True

    def set(self, section, property, value):
        """Set a value and save."""
        self.config.set(section, property, value)
        self.write()
        return True

    def get(self, section, property):
        """Get a value"""
        value = self.config.get(section, property)
        return value

    def remove_option(self, sectname, optionname):
        """Remove a property & it's value, then save."""
        self.config.remove_option(sectname, optionname)
        self.write()

    def add_section(self, sectname):
        """Add a section and save."""
        self.config.add_section(sectname)
        self.write()

    def remove_section(self, sectname):
        """Remove a section and save."""
        self.config.remove_section(sectname)
        self.write()    

    def sections(self):
        """Return all the sections of the ConfigFile"""
        return self.config.sections()

    def options(self, section):
        """Return all the option of a section of the ConfigFile"""
        return self.config.options(section)

    def has_section(self, section):
        """Has a section?"""
        return self.config.has_section(section)

    def has_option(self, section, option):
        """Has an option?"""
        return self.config.has_option(section, option)

    def getOldDriver(self):
        """Wrapper funtion"""
        return self.get('Configuration', 'OldDriver')

    def setOldDriver(self, oldDriver):
        """Wrapper funtion"""
        self.set('Configuration', 'OldDriver', oldDriver)

    def getConfigType(self):
        """Wrapper funtion"""
        return self.get('Configuration', 'Preconfigured')

    def setConfigType(self, ctype):
        """Wrapper funtion"""
        if ctype.lower() == 'aiglx' or ctype.lower() == 'xgl' or ctype.lower() == 'noglx' or ctype.lower() == 'manual':
            self.set('Configuration', 'Preconfigured', ctype)
        else:
            print 'Bad ctype'
            return False

    def getGdmXgl(self):
        """Wrapper funtion"""
        return toBool(self.get('ManualOptions', 'GdmXgl'))

    def setGdmXgl(self, bool):
        """Wrapper funtion"""
        if bool:
            self.set('ManualOptions', 'GdmXgl', 'True')
        else:
            self.set('ManualOptions', 'GdmXgl', 'False')

    def getKdmXgl(self):
        """Wrapper funtion"""
        return toBool(self.get('ManualOptions', 'KdmXgl'))

    def setKdmXgl(self, bool):
        """Wrapper funtion"""
        if bool:
            self.set('ManualOptions', 'KdmXgl', 'True')
        else:
            self.set('ManualOptions', 'KdmXgl', 'False')

    def getAiglxFlag(self):
        """Wrapper funtion"""
        return toBool(self.get('ManualOptions', 'AiglxFlag'))

    def setAiglxFlag(self, bool):
        """Wrapper funtion"""
        if bool:
            self.set('ManualOptions', 'AiglxFlag', 'True')
        else:
            self.set('ManualOptions', 'AiglxFlag', 'False')

    def getComposite(self):
        """Wrapper funtion"""
        print toBool(self.get('ManualOptions', 'Composite'))
        return toBool(self.get('ManualOptions', 'Composite'))

    def setComposite(self, bool):
        """Wrapper funtion"""
        if bool:
            self.set('ManualOptions', 'Composite', 'True')
        else:
            self.set('ManualOptions', 'Composite', 'False')

    def getActive(self):
        """Wrapper funtion"""
        return toBool(self.get('Configuration', 'Active'))

    def setActive(self, bool):
        """Wrapper funtion"""
        self.set('Configuration', 'Active', bool)


