# -*- coding: UTF-8 -*-
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright (C) 2006-2009 Stewart Adam
"""
Constants and translatable messages for livnaConfigDisplay
"""

"""
REMEMBER:
- Let's try to keep all the standards, internationalization and constant things in here as much as possible
- Adding a new module? We have to enter it into MODULE_LIST for it to work!
- TODO when adding a new module:
        (1) Add to MODULE_LIST below
        (2) Add a elif clause in __init__ of ConfigDialog in ConfigurationDialog.py
        (3) If needed, add a new XGL_COMMAND_[STARTSWITH] command
        (4) If needed, add a new elif clause to getVendor() of LivnaUtils in Utils.py for a new minorVendor type

"""

import livnaConfigDisplay
import os, os.path
import commands

#----------------------------------------
# APPLICATION GLOBAL CONST                   
#----------------------------------------
VERSION = livnaConfigDisplay.__version__
I18N_DOMAIN = "livna-config-display"
GDM_XGL_CONFIG_LINE = "0=Xgl"
MODULE_LIST = ["fglrx", "catalyst", "nvidia", "nvidia-legacy", "nvidia-96xx", "nvidia-173xx", "nvidia-beta", "nvidia-newest"]
XGL_COMMAND_FGLRX = "%s/usr/bin/Xgl -ac -accel glx:pbuffer -accel xv:pbuffer"
XGL_COMMAND_NVIDIA = "%s/usr/bin/Xgl -ac -accel glx:pbuffer -accel xv:fbo"
XGL_COMMAND_OTHER="%s/usr/bin/Xgl -ac -accel glx:pbuffer -accel xv"
# To enable if/when both legacy and current mods can be load at the same time
# already usefull for debuging, if SHOW_ALL_INSTALLED_MODS and DEBUG is 
# set to True, all driver supported by the app is showed in both UI's.
#SHOW_ALL_INSTALLED_MODS = False
# You can never have two mods on at once: The RPMs conflict eachother...
DEBUG = False
BACKUP_NAME = '.livna-config-backup'

## I18N
try: 
    import gettext
    import sys
    if sys.version_info[0] == 2:
        t = gettext.translation(I18N_DOMAIN)
        _ = t.gettext
    else:
        gettext.bindtextdomain(I18N_DOMAIN, '/usr/share/locale')
        gettext.textdomain(I18N_DOMAIN)
        _ = gettext.gettext
except:
    def _( str ):
        """pass given string as-is"""
        return str

#----------------------------------------
# FILE LOCATIONS CONST               
#----------------------------------------
XORG_CONF_FILE = "/etc/X11/xorg.conf"
GDM_CUSTOMCONF_FILE = "/etc/gdm/custom.conf"
KDM_CUSTOMCONF_FILE = "/etc/kde/kdm/kdmrc"
APP_PATH = "/usr/share/livna-config-display"
ICON_PATH = "/usr/share/pixmaps/livna-config-display.png"
GLADE_FILE = APP_PATH + "/livna-config-display.glade"
STATUS_FILE = "/etc/sysconfig/livna-config-display"
LD_CONF_FILE = "/etc/ld.so.conf.d/%s.conf"

if os.uname()[4].lower() in ['x86_64', 'ppc64']:
    LIBDIR = '/usr/lib64/'
else:
    LIBDIR = '/usr/lib/'

#----------------------------------------
# FILE-DEPENDENT CONFIGS               
#----------------------------------------
status, output = commands.getstatusoutput('rpm -q gdm')
if os.path.exists(GDM_CUSTOMCONF_FILE) or status == os.EX_OK:
    GDM_EXISTS = True
else:
    GDM_EXISTS = False
status, output = commands.getstatusoutput('rpm -q kdebase')
if os.path.exists(KDM_CUSTOMCONF_FILE) or status == os.EX_OK:
    KDM_EXISTS = True
else:
    KDM_EXISTS = False
if os.path.exists('/usr/bin/Xgl'):
    XGL_EXISTS = True
else:
    XGL_EXISTS = False

#----------------------------------------
# I18N MESSAGES CONST
#----------------------------------------
MSG_TRACEBACK = _("Traceback: %s")
MSG_CONF_APPLIED = _("Configuration Applied.")
MSG_ERROR_CANNOT_IMPORT_GTK = _("Cannot import GTK. Please try setting DISPLAY and try again")
MSG_ERROR_CANNOT_READ = _("Cannot read file '%s'")
MSG_ERROR_CANNOT_WRITE = _("Cannot write file '%s'")
MSG_PERMISSION_ERROR = _("\nPlease make sure you have permissions to modify the necessary configuration file(s).")
MSG_CONF_APPLY_ERROR = _("An error occured while applying the configuration. Attempting to restore backups.") + MSG_PERMISSION_ERROR
MSG_CONF_BACKUP_ERROR = _("An error occured while backing up the file '%s'") + MSG_PERMISSION_ERROR
MSG_CONF_RESTORE_ERROR = _("An error occured while restoring the file '%s'")  + MSG_PERMISSION_ERROR
MSG_XGL_NOT_FOUND = _("Xgl was not found. Skipping configuration of Xgl for GDM and KDM.")
MSG_GDM_NOT_FOUND = _("GDM was not found. Skipping configuration of Xgl for GDM.")
MSG_KDM_NOT_FOUND = _("KDM was not found. Skipping configuration of Xgl for KDM.")
MSG_RESTART_X = _("To complete the configuration, the X server must be restarted.\nThe easiest way to do this is to restart your computer.")
DISABLE_ALL = _('Disable All')
MSG_DRIVER_NOT_FOUND = _('The AMD (\'fglrx\') or nVidia (\'nvidia\') driver was not found on the system.\nIf one is installed, please try reinstalling it.')
XORG_NOT_FOUND = _('Could not read the Xorg configuration file: Installing sample configuration to work with.')
MSG_NONE_FOUND = _('None found')
MSG_NONE = _('None')


