# -*- coding: UTF-8 -*-
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright (C) 2006 Van Assche Alphonse <alcapcom@gmail.com>
# Copyright (C) 2006, 2007 Stewart Adam

"""
The client to the livnaConfigDisplay libraries.
"""

import sys
import string
import getopt
#import gettext

from livnaConfigDisplay.const import *
from livnaConfigDisplay.const import _

from livnaConfigDisplay import Utils
from livnaConfigDisplay.ConfigDisplay import LivnaConfigDisplay
from livnaConfigDisplay.GlxConfig import GlxConfig
from livnaConfigDisplay import livnaConfigDisplayError

#gettext.bindtextdomain (I18N_DOMAIN, "/usr/share/locale")
#gettext.textdomain (I18N_DOMAIN)

## Global vars
DEBUG = True
def usage():
    """Print version, usage..."""
    print _("""livna-config-display v%s
Usage: livna-config-display [OPTIONS]
Options:

General:
  -h, --help\n\tDisplay this help message
  -v, --verbose\n\tIncrease verbosity
  --gui\n\tUse graphical interface (default)
  --tui\n\tUse text interface
  --active on|off\n\tShould livna-config-display edit configuration files?

Automatic configuration:
  -a, --auto-aiglx\n\tAutomatically configure settings for AIGLX
  -x, --auto-xgl\n\tAutomatically configure settings for Xgl
  -d, --disable-glx\n\tDisable everything concerning AIGLX and Xgl

Advanced configuration:
  --aiglx-flag on|off\n\tEnable or disable AIGLX flag
  --composite on|off\n\tEnable or disable the Composite extension
  --xgl-gdm on|off\n\tEnable or disable the settings Xgl for GDM
  --xgl-kdm on|off\n\tEnable or disable the settings Xgl for KDM
  
 Example 1: livna-config-display --tui -a
\t(TUI mode, automatically configure for AIGLX)
 Example 2: livna-config-display --composite on --xgl-gdm off
\t(Enables Composite, disables Xgl for GDM)""" % VERSION)

def convertValue(value):
    """    Convert synonyms for bool args to bools"""
    if value.lower() in ["on", "enable", "true", "1"]:
        return True
    elif value.lower() in ["off", "disable", "false", "0"]:
        return False
    else:
        raise livnaConfigDisplayError(_('Invalid argument passed: %s' % value))

## Vars
verboseOutput = False

# Print configuration applied message? Default to yes.
msg = True
# Default to GUI
ui = True

# CD = ConfigDisplay, the wrapper for our functions
CD = LivnaConfigDisplay(verboseOutput)
Utils.setVerbose(verboseOutput)
vendor = Utils.getVendor()
CD.Glx = GlxConfig(verboseOutput)
if vendor == 'False':
    # Just for now... We check again later.
    isLegacy = False
elif vendor.endswith('legacy'):
    isLegacy = True
else:
    isLegacy = False

avalableOptions = ["help", "verbose", "gui", "tui", "aiglx-flag=", \
                   "composite=", "xgl-gdm=", "kdm-xgl", \
                   "disable-glx", "auto-aiglx", "auto-xgl", "active=" ]

#if __name__ == '__main__':
#    signal.signal(signal.SIGINT, signal.SIG_DFL)
try:
    (opts, rest_args) = getopt.getopt(sys.argv[1:],"vo:hvdax", avalableOptions)
except (getopt.GetoptError), e:
    print e, ""
    usage()
    sys.exit(1)

# Do backups now.
try:
    CD.doAllBackups()
except livnaConfigDisplayError, (bkupErrMsg):
    print bkupErrMsg
    sys.exit(1)

# Parse args, take action
for (opt, value) in opts:
    if opt == "-v" or opt == "--verbose":
        verboseOutput = True
        CD.setVerbose(verboseOutput)
        msg = False
    if opt == "--tui":
        ui = False
        msg = False
        if vendor == 'False':
            print MSG_DRIVER_NOT_FOUND
            sys.exit(1)
    if opt == "--gui":
        ui = True
        msg = False
    if opt == "-h" or opt == "--help":
        usage()
        sys.exit(1)
    try:
        if opt == "-d" or opt == "--disable-glx":
            CD.Glx.disableAllGlxStuff()
            ui = False
        if opt == "-a" or opt == "--auto-aiglx":
            CD.Glx.enableAiglx()
            ui = False
        if opt == "-x" or opt == "--auto-xgl":
            CD.Glx.enableXgl()
            ui = False
        if opt == "--active":
            ui = True
            CD.Glx.setActive(convertValue(value))
            ui = False
        if opt == "--aiglx-flag":
            CD.Glx.setAiglxFlag(convertValue(value))
            ui = False
        if opt == "--composite":
            CD.Glx.setComposite(convertValue(value))
            ui = False
        if opt == "--xgl-gdm":
            CD.Glx.setGDMXgl(convertValue(value))
            ui = False
        if opt == "--kdm-xgl":
            CD.Glx.setKdmXgl(convertValue(value))
            ui = False
        if msg:
            CD.Glx.storeconf()
            print MSG_CONF_APPLIED
    except livnaConfigDisplayError, (errMsg):
       print MSG_CONF_APPLY_ERROR
       try:
           CD.doAllRestores()
       except livnaConfigDisplayError, (bkupErrMsg):
           print MSG_CONF_RESTORE_ERROR + '\n' + MSG_TRACEBACK % (str(errMsg)) + '\n\n' + str(bkupErrMsg)
           sys.exit(1)
    except:
        print MSG_CONF_APPLY_ERROR
        sys.exit(1)

if ui:
    # If the user try to use the GUI and a good X configurations is not avalable,
    # he should see a warning.
    try:
        import gtk
    except:
        print MSG_ERROR_CANNOT_IMPORT_GTK
        sys.exit(1)
    from ConfigurationDialog import *
    GUI = ConfigDialog(CD)
    gtk.main()


